@@ -1,8 +1,8 @@
 
-context("tex_contour")
-v <- reshape2::melt(volcano)
-g <- ggplot(v, aes(Var1, Var2, z = value)) +
-    geom_contour()
+# context("tex_contour")
+# v <- reshape2::melt(volcano)
+# g <- ggplot(v, aes(Var1, Var2, z = value)) +
+#     geom_contour()
 
 # test_that("default text works", {
 #     expect_doppelganger("text_contour-default", g + geom_text_contour())
